@@ -1,16 +1,20 @@
 import json
 import yaml
 
+from datetime import datetime, timezone
+
 def convert_dnstap(fmt, tapmsg):
     """convert dnstap message"""
+    tapmsg["datetime"] = datetime.fromtimestamp(tapmsg["timestamp"], tz=timezone.utc).isoformat()
+  
     if fmt == "text":
         msg_list = []
-        msg_list.append("%s" % tapmsg["timestamp"])
+        msg_list.append("%s" % tapmsg["datetime"])
         msg_list.append("%s" % tapmsg["identity"])
         msg_list.append("%s" % tapmsg["message"])
         msg_list.append("%s" % tapmsg["rcode"]) 
-        msg_list.append("%s" % tapmsg["source-ip"])
-        msg_list.append("%s" % tapmsg["source-port"])
+        msg_list.append("%s" % tapmsg["query-ip"])
+        msg_list.append("%s" % tapmsg["query-port"])
         msg_list.append("%s" % tapmsg["family"])
         msg_list.append("%s" % tapmsg["protocol"])
         msg_list.append("%sb" % tapmsg["length"])
